@@ -877,15 +877,15 @@ class World:
     def __init__(self, name="PyBlockWorld"):
         self.window = Window(width=800, height=600, 
             caption=name, resizable=True)
-        self.window.unknown_key_pressed = self.__unknown_key_pressed
+        self.window.unknown_key_pressed = self.__build_key_function
 
     def build_key_pressed(self):
-        pass
+        print("b pressed")
 
-    def __unknown_key_pressed(self, symbol):
+    def __build_key_function(self, symbol):
         #print(symbol, "pressed")
         if symbol == key.B:
-            self.build_key_pressed()
+            self.build_key_pressed(self)
 
     def setBlock(self, x,y,z, blocktype):
         pos = int(x),int(y),int(z)
@@ -956,29 +956,27 @@ def setup():
 def main():
     from pyblockworld import World
 
-    class MyWorld(World):
-        def __init__(self):
-            super().__init__()
+    # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
+    def b_key_pressed(world:World):
+        print("B pressed.")
+        x,y,z = world.player_position()
 
-        # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
-        def build_key_pressed(world:World):
-            print("B pressed.")
-            x,y,z = world.player_position()
+        # Neue Blöcke können mit setBlock gesetzt werden.
+        # Verfügbare Materialien stehen in World.MATERIALS und umfassen
+        # air, default:brick, default:stone, default:sand, default:grass
+        print("Block types", World.MATERIALS)
+        world.setBlock(x,y,z, "default:brick")
 
-            # Neue Blöcke können mit setBlock gesetzt werden.
-            # Verfügbare Materialien stehen in World.MATERIALS und umfassen
-            # air, default:brick, default:stone, default:sand, default:grass
-            print("Block types", World.MATERIALS)
-            world.setBlock(x,y,z, "default:brick")
-
-            # Mehrere Blöcke auf einmal abseits des Spielers platzieren
-            x,y,z = x,y,z+3
-            world.setBlocks(x,y,z, x+3,y+3,z+3, "default:grass")
+        # Mehrere Blöcke auf einmal abseits des Spielers platzieren
+        x,y,z = x,y,z+3
+        world.setBlocks(x,y,z, x+3,y+3,z+3, "default:grass")
         
     # Erstellen einer neuen Welt
-    my_world = MyWorld()
+    world = World()
+    # Die Funktion für die build-Taste (b) wird zugewiesen
+    world.build_key_pressed = b_key_pressed
     # Die Welt wird gestartet
-    my_world.run()
+    world.run()
     
 
 if __name__ == '__main__':
